==> ejc-sddjsorg-api-3.0.0-20211103.074646-142-sources.jar: com/ejianc/business/production/vo/TransferorVO.java <==
package com.ejianc.business.production.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 产权登记-受让方
 * 
 * @author generator
 * 
 */
public class TransferorVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private String transferorName; // 受让方名称
    private Long transferorNameId;
    private String unifiedSocialCreditCode; // 统一社会信用代码
    private String orgNature; // 企业性质
    private java.math.BigDecimal holdingRatio; // 受让方持有比例
    private String dealPriceBig; // 成交价格(大写)
    private java.math.BigDecimal audit; // 审计值
    private String auditBig; // 审计值(大写)
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date acceptanceDate; // 受理时间
    private Long pid; // 父类id
    

    /**
     * 受让方名称
     */
    public String getTransferorName() {
        return transferorName;
    }

    public void setTransferorName(String transferorName) {
        this.transferorName = transferorName;
    }

    /**
     * 统一社会信用代码
     */
    public String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用代码
     */
    public void setUnifiedSocialCreditCode(String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 企业性质
     */
    public String getOrgNature() {
        return orgNature;
    }

    /**
     * 企业性质
     */
    public void setOrgNature(String orgNature) {
        this.orgNature = orgNature;
    }
    /**
     * 受理时间
     */
    public java.util.Date getAcceptanceDate() {
        return acceptanceDate;
    }

    /**
     * 受理时间
     */
    public void setAcceptanceDate(java.util.Date acceptanceDate) {
        this.acceptanceDate = acceptanceDate;
    }
    /**
     * 父类id
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 父类id
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getTransferorNameId() {
        return transferorNameId;
    }

    public void setTransferorNameId(Long transferorNameId) {
        this.transferorNameId = transferorNameId;
    }

    public BigDecimal getHoldingRatio() {
        return holdingRatio;
    }

    public void setHoldingRatio(BigDecimal holdingRatio) {
        this.holdingRatio = holdingRatio;
    }

    public String getDealPriceBig() {
        return dealPriceBig;
    }

    public void setDealPriceBig(String dealPriceBig) {
        this.dealPriceBig = dealPriceBig;
    }

    public BigDecimal getAudit() {
        return audit;
    }

    public void setAudit(BigDecimal audit) {
        this.audit = audit;
    }

    public String getAuditBig() {
        return auditBig;
    }

    public void setAuditBig(String auditBig) {
        this.auditBig = auditBig;
    }
}

==> ejc-sddjsorg-api-3.0.0-20211104.023412-146-sources.jar: com/ejianc/business/production/vo/TransferorVO.java <==
package com.ejianc.business.production.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 产权登记-受让方
 * 
 * @author generator
 * 
 */
public class TransferorVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private String transferorName; // 受让方名称
    private Long transferorNameId;
    private String unifiedSocialCreditCode; // 统一社会信用代码
    private String orgNature; // 企业性质
    private java.math.BigDecimal holdingRatio; // 受让方持有比例
    private String dealPriceBig; // 成交价格(大写)
    private java.math.BigDecimal audit; // 审计值
    private String auditBig; // 审计值(大写)
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date acceptanceDate; // 受理时间
    private Long pid; // 父类id
    private String transferorNature;// 受让性质

    /**
     * 受让方名称
     */
    public String getTransferorName() {
        return transferorName;
    }

    public void setTransferorName(String transferorName) {
        this.transferorName = transferorName;
    }

    /**
     * 统一社会信用代码
     */
    public String getUnifiedSocialCreditCode() {
        return unifiedSocialCreditCode;
    }

    /**
     * 统一社会信用代码
     */
    public void setUnifiedSocialCreditCode(String unifiedSocialCreditCode) {
        this.unifiedSocialCreditCode = unifiedSocialCreditCode;
    }
    /**
     * 企业性质
     */
    public String getOrgNature() {
        return orgNature;
    }

    /**
     * 企业性质
     */
    public void setOrgNature(String orgNature) {
        this.orgNature = orgNature;
    }
    /**
     * 受理时间
     */
    public java.util.Date getAcceptanceDate() {
        return acceptanceDate;
    }

    /**
     * 受理时间
     */
    public void setAcceptanceDate(java.util.Date acceptanceDate) {
        this.acceptanceDate = acceptanceDate;
    }
    /**
     * 父类id
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 父类id
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getTransferorNameId() {
        return transferorNameId;
    }

    public void setTransferorNameId(Long transferorNameId) {
        this.transferorNameId = transferorNameId;
    }

    public BigDecimal getHoldingRatio() {
        return holdingRatio;
    }

    public void setHoldingRatio(BigDecimal holdingRatio) {
        this.holdingRatio = holdingRatio;
    }

    public String getDealPriceBig() {
        return dealPriceBig;
    }

    public void setDealPriceBig(String dealPriceBig) {
        this.dealPriceBig = dealPriceBig;
    }

    public BigDecimal getAudit() {
        return audit;
    }

    public void setAudit(BigDecimal audit) {
        this.audit = audit;
    }

    public String getAuditBig() {
        return auditBig;
    }

    public void setAuditBig(String auditBig) {
        this.auditBig = auditBig;
    }

    public String getTransferorNature() {
        return transferorNature;
    }

    public void setTransferorNature(String transferorNature) {
        this.transferorNature = transferorNature;
    }
}
